<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>ShowAllBlocks</name>
    <message>
        <source>&amp;Show all</source>
        <translation type="vanished">全部显示(&amp;S)</translation>
    </message>
    <message>
        <location filename="../ShowAllBlocksInit.js" line="+2"/>
        <source>&amp;Show All Blocks</source>
        <translation>显示全部块(&amp;S)</translation>
    </message>
</context>
</TS>
